@@ -17,6 +17,9 @@
  * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+
+#include <bctoolbox/defs.h>
+
 #ifdef HAVE_CONFIG_H
 #include "ortp-config.h"
 #endif
@@ -159,7 +162,7 @@ int rtp_session_add_telephone_event(RtpSession *session,
 	mblk_t *mp=packet;
 	telephone_event_t *event_hdr;
 
-
+	(void)session;
 	/* find the place where to add the new telephony event to the packet */
 	while(mp->b_cont!=NULL) mp=mp->b_cont;
 	/* see if we need to allocate a new mblk_t */
